#!/usr/bin/python

#=============#
# Description #
#=============#
#
# Submits a job to trim nextera adapters from fastqs
#



#SBATCH --job-name=trim

#SBATCH --output=../log/%j.txt
#SBATCH --error=../log/%j.out

#SBATCH --partition=compute

#SBATCH --nodes=1
#SBATCH --ntasks=1
#SBATCH --cpus-per-task=12
#SBATCH --nodes=1
#SBATCH --mem=16384

#SBATCH --mail-user=dec@u.northwestern.edu
#SBATCH --workdir=/lscr2/andersenlab/kml436/demultiplex/demultiplexed

# Parse arguments

import sys, os
import glob

fq = sys.argv[1]

fq1 = glob.glob("{fq}*1.fq.gz".format(fq=fq))
fq2 = glob.glob("{fq}*2.fq.gz".format(fq=fq))

assert(len(fq1) == 1)
assert(len(fq2) == 1)

fq1, fq2 = fq1[0], fq2[0]

# Trim Adapters
os.system("java -jar /exports/people/andersenlab/dec211/bin/trimmomatic.jar PE -threads 12 {fq1} {fq2} {fq}-paired-1.fq.gz {fq}-unpaired-1.fq.gz {fq}-paired-2.fq.gz {fq}-unpaired-2.fq.gz ILLUMINACLIP:/exports/people/andersenlab/dec211/bin/adapters/NexteraPE-PE.fa:2:80:10 MINLEN:50".format(**locals()))

# Run fastqc on before and after
comm = "echo -n {fq1} {fq2} {fq}-paired-1.fq.gz {fq}-unpaired-1.fq.gz {fq}-paired-2.fq.gz {fq}-unpaired-2.fq.gz | xargs -d ' ' -t -P 6  -I {{}} sh -c 'fastqc {{}}'".format(**locals())
os.system(comm)

# Run fastqc afterwords
os.system("echo -n {fq1} {fq2} | xargs -d ' ' -t -P 2  -I {{}} sh -c 'fastqc {{}}'".format(**locals()))

